==> syncope-2.0.8-source-release.zip: syncope-2.0.8/core/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/validation/entity/ReportValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa.validation.entity;

import java.text.ParseException;
import java.util.HashSet;
import java.util.Set;
import javax.validation.ConstraintValidatorContext;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.Transformer;
import org.apache.syncope.common.lib.report.ReportletConf;
import org.apache.syncope.common.lib.types.EntityViolationType;
import org.apache.syncope.core.persistence.api.entity.Report;
import org.quartz.CronExpression;

public class ReportValidator extends AbstractValidator<ReportCheck, Report> {

    @Override
    @SuppressWarnings("ResultOfObjectAllocationIgnored")
    public boolean isValid(final Report object, final ConstraintValidatorContext context) {
        boolean isValid = true;

        if (object.getCronExpression() != null) {
            try {
                new CronExpression(object.getCronExpression());
            } catch (ParseException e) {
                LOG.error("Invalid cron expression '" + object.getCronExpression() + "'", e);
                isValid = false;

                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(
                        getTemplate(EntityViolationType.InvalidReport, "Invalid cron expression")).
                        addPropertyNode("cronExpression").addConstraintViolation();
            }
        }

        Set<String> reportletNames = CollectionUtils.collect(object.getReportletConfs(),
                new Transformer<ReportletConf, String>() {

                    @Override
                    public String transform(final ReportletConf input) {
                        return input.getName();
                    }
                }, new HashSet<String>());
        if (reportletNames.size() != object.getReportletConfs().size()) {
            LOG.error("Reportlet name must be unique");
            isValid = false;

            context.disableDefaultConstraintViolation();
            context.buildConstraintViolationWithTemplate(
                    getTemplate(EntityViolationType.InvalidReport, "Reportlet name must be unique")).
                    addPropertyNode("reportletConfs").addConstraintViolation();
        }

        return isValid;
    }
}

==> syncope-2.0.14-source-release.zip: syncope-2.0.14/core/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/validation/entity/ReportValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa.validation.entity;

import java.text.ParseException;
import java.util.HashSet;
import java.util.Set;
import javax.validation.ConstraintValidatorContext;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.Transformer;
import org.apache.syncope.common.lib.report.ReportletConf;
import org.apache.syncope.common.lib.types.EntityViolationType;
import org.apache.syncope.core.persistence.api.entity.Report;
import org.quartz.CronExpression;

public class ReportValidator extends AbstractValidator<ReportCheck, Report> {

    @Override
    @SuppressWarnings("ResultOfObjectAllocationIgnored")
    public boolean isValid(final Report report, final ConstraintValidatorContext context) {
        context.disableDefaultConstraintViolation();

        boolean isValid = true;

        if (isHtml(report.getName())) {
            context.buildConstraintViolationWithTemplate(
                    getTemplate(EntityViolationType.InvalidName, "Invalid name")).
                    addPropertyNode("name").addConstraintViolation();

            isValid = false;
        }

        if (report.getCronExpression() != null) {
            try {
                new CronExpression(report.getCronExpression());
            } catch (ParseException e) {
                LOG.error("Invalid cron expression '" + report.getCronExpression() + "'", e);
                isValid = false;

                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(
                        getTemplate(EntityViolationType.InvalidReport, "Invalid cron expression")).
                        addPropertyNode("cronExpression").addConstraintViolation();
            }
        }

        Set<String> reportletNames = CollectionUtils.collect(report.getReportletConfs(),
                new Transformer<ReportletConf, String>() {

            @Override
            public String transform(final ReportletConf input) {
                return input.getName();
            }
        }, new HashSet<String>());
        if (reportletNames.size() != report.getReportletConfs().size()) {
            LOG.error("Reportlet name must be unique");
            isValid = false;

            context.disableDefaultConstraintViolation();
            context.buildConstraintViolationWithTemplate(
                    getTemplate(EntityViolationType.InvalidReport, "Reportlet name must be unique")).
                    addPropertyNode("reportletConfs").addConstraintViolation();
        }

        return isValid;
    }
}
